@@ -79,10 +79,18 @@ if(status==500)
 {decode <- fromJSON2(reader$value()); message <- decode$exception; stop(paste("HTTP request was unsuccessful. Status code = ",status,", Error message = ",message,sep=""))}
 
 if(status>=400)
-    {contTypes <- which(names(h)=='Content-Type')
-    if(length(contTypes)>1 & h[contTypes[2]]=="application/json;charset=utf-8")
-        {decode <- fromJSON2(reader$value()); message<-decode$exception; stop (paste("HTTP request was unsuccessful. Status code = ",status,", Error message = ",message,sep=""))} else
-    {stop(paste("HTTP request was unsuccessful. Status code = ",status,", Error message = ",message,sep=""))}}
+{
+    contTypes <- which(names(h)=='Content-Type')
+    if(length(contTypes)>0 && (tolower(h[contTypes[1]])=="application/json;charset=utf-8" || tolower(h[contTypes[2]])=="application/json;charset=utf-8"))
+    {
+        decode <- fromJSON2(reader$value());
+        message<-decode$exception;
+        stop (paste("HTTP request was unsuccessful. Status code = ",status,", Error message = ",message,sep=""))
+    } else
+    {
+        stop(paste("HTTP request was unsuccessful. Status code = ",status,", Error message = ",message,sep=""))
+    }
+}
 
 newdata <- fromJSON2(reader$value())
 
